Client

Struct Client 

pub struct Client {
    pub api_key: String,
}
Finnhub API Client object.

Fields

api_key: String

API key from the Finnhub dashboard.

Implementations

Source

impl Client

pub fn new(api_key: String) -> Self

Creates a new Finnhub Client

pub async fn symbol_lookup( self, query: String, ) -> Result<SymbolLookup, ExitFailure>

Lookups a symbol in the Finnhub API

pub async fn stock_symbol( self, exchange: String, ) -> Result<Vec<StockSymbol>, ExitFailure>

Returns a list of supported stocks given the exchange.

pub async fn company_profile2( self, symbol: String, ) -> Result<CompanyProfile, ExitFailure>

Returns the profile of the company specified.

pub async fn market_news( self, category: String, ) -> Result<Vec<MarketNews>, ExitFailure>

Returns the latest market news in the given category.

pub async fn company_news( self, symbol: String, from: String, to: String, ) -> Result<Vec<CompanyNews>, ExitFailure>

Returns the company news from the company specified in the given time period.

pub async fn peers(self, symbol: String) -> Result<Vec<String>, ExitFailure>

Returns the specified companies peers.

pub async fn quote(self, symbol: String) -> Result<CompanyQuote, ExitFailure>

Returns the specified company’s current stock quote.